@echo off
%windir%\System32\more +8 "%~f0" > "%temp%\%~n0.ps1"
powershell -NoProfile -ExecutionPolicy Bypass -File "%temp%\%~n0.ps1" %*
del %temp%\%~n0.ps1
pause
exit /b

*** Ab hier PowerShell ***
<#
.SYNOPSIS
    Creates an VPN user tunnel connection.
.PARAMETER ProfileName
    Name of the VPN profile to be created.
.EXAMPLE
    .\TER-New-VPNConnection -ProfileName 'TerGroup VPN Extern X.X'
    Creates an  VPN user tunnel profile named "TerGroup VPN Extern X.X" for the currently logged on user.
.DESCRIPTION
    This script will create an VPN user tunnel on supported Windows 10 devices for the TerGroup company. 
.LINK for root & intermediate certificates to establish the connection
    http://ca.tergroup.com/
.NOTES
    Version:            4.0
    Creation Date:      January 14, 2022
    Last Updated:       March 28, 2023
    Special Note:       This script adapted from guidance originally published by Microsoft.
    Original Author:    Microsoft Corporation
    Original Script:    https://docs.microsoft.com/en-us/windows-server/remote/remote-access/vpn/always-on-vpn/deploy/vpn-deploy-client-vpn-connections#bkmk_fullscript
    Author:             Burhan Soyupek
    Organization:       TER Chemicals GmbH & Co. KG (Member of TER Group)
    Contact:            b.soyupek@terchemicals.com
    Support contact:    helpdesk@terchemicals.com
    Web Site:           https://terchemicals.com/
#>
function TER-New-VPNConnection {
    [CmdletBinding(SupportsShouldProcess)]

    Param (
     [Parameter(HelpMessage = 'Enter a name for the VPN profile.')] 
     [ValidateNotNullOrEmpty()]      
     [Alias("Name", "ConnectionName")]
     [string]$ProfileName
    )

    #region disconnecten und löschen alter VPN Profile
    #Bei neuer Version muss das alte VPN erst entfernt werden.
    $CurrentVPN = Get-VpnConnection | Where-Object Name -like "TERGroup Extern VPN*"

    foreach ($VPN in $CurrentVPN){
        if($VPN.ConnectionStatus -eq "Connected"){
        rasdial $VPN.Name /DISCONNECT
        Write-Host "VPN Verbindung getrennt."
        }
    }

    Start-Sleep -Seconds 2

    foreach ($VPN in $CurrentVPN){
    Remove-VpnConnection $VPN.Name -Force}

    start-sleep -Seconds 2

    $CheckVPNProfile = Get-VpnConnection | Where-Object Name -like "TERGroup Extern VPN*"

    if (!($Null -eq $CheckVPNProfile)) {
        Write-Warning "Die VPN Verbindungen konnten nicht gelöscht werden. Bitte Löschen Sie sie manuell. `n
        The VPN profiles could not been removed. Please remove them manually. Exiting Script."
        Exit
    }
    else { Write-Host "VPN wurde gelöscht. Das zu installierende VPN Profil wird ausgeführt." }

    #endregion

    #region PBK-Config

$Pbk_config = '
Encoding=1
PBVersion=6
Type=2
AutoLogon=0
UseRasCredentials=1
LowDateTime=-1855006048
HighDateTime=31023462
DialParamsUID=13175140
Guid=97D36ABE5D9667458E72FBB604C13EE7
VpnStrategy=6
ExcludedProtocols=0
LcpExtensions=1
DataEncryption=256
SwCompression=0
NegotiateMultilinkAlways=0
SkipDoubleDialDialog=0
DialMode=0
OverridePref=15
RedialAttempts=3
RedialSeconds=60
IdleDisconnectSeconds=0
RedialOnLinkFailure=1
CallbackMode=0
CustomDialDll=
CustomDialFunc=
CustomRasDialDll=
ForceSecureCompartment=0
DisableIKENameEkuCheck=0
AuthenticateServer=0
ShareMsFilePrint=1
BindMsNetClient=1
SharedPhoneNumbers=0
GlobalDeviceSettings=0
PrerequisiteEntry=
PrerequisitePbk=
PreferredPort=VPN2-0
PreferredDevice=WAN Miniport (IKEv2)
PreferredBps=0
PreferredHwFlow=0
PreferredProtocol=0
PreferredCompression=0
PreferredSpeaker=0
PreferredMdmProtocol=0
PreviewUserPw=1
PreviewDomain=1
PreviewPhoneNumber=0
ShowDialingProgress=1
ShowMonitorIconInTaskBar=1
CustomAuthKey=25
CustomAuthData=31444243190000005700000001000000570000000100000001000000020000002E000000150000000100000014000000EAC30CC62CDFE8969A0D9AD2DD039163
CustomAuthData=4BC5D349000001000000170000001A000000010000000000000000000000000000000000000000
AuthRestrictions=128
IpPrioritizeRemote=0
IpInterfaceMetric=0
IpHeaderCompression=0
IpAddress=0.0.0.0
IpDnsAddress=0.0.0.0
IpDns2Address=0.0.0.0
IpWinsAddress=0.0.0.0
IpWins2Address=0.0.0.0
IpAssign=1
IpNameAssign=1
IpDnsFlags=0
IpNBTFlags=1
TcpWindowSize=0
UseFlags=2
IpSecFlags=0
IpDnsSuffix=tergroup.net
Ipv6Assign=1
Ipv6Address=::
Ipv6PrefixLength=0
Ipv6PrioritizeRemote=0
Ipv6InterfaceMetric=0
Ipv6NameAssign=1
Ipv6DnsAddress=::
Ipv6Dns2Address=::
Ipv6Prefix=0000000000000000
Ipv6InterfaceId=0000000000000000
DisableClassBasedDefaultRoute=1
DisableMobility=0
NetworkOutageTime=0
IDI=
IDR=
ImsConfig=0
IdiType=0
IdrType=0
ProvisionType=0
PreSharedKey=
CacheCredentials=0
NumCustomPolicy=0
NumEku=0
UseMachineRootCert=0
Disable_IKEv2_Fragmentation=0
PlumbIKEv2TSAsRoutes=0
NumServers=1
ServerListServerName=vpn.terchemicals.com
ServerListFriendlyName=vpn.terchemicals.com
RouteVersion=1
NumRoutes=8
Routes=0100000002000000120000000AC9000000000000000000000000000000000000000000000100000002000000160000000ACA0000000000000000000000000000
Routes=00000000000000000100000002000000160000000ACA040000000000000000000000000000000000000000000100000002000000120000000ACB000000000000
Routes=000000000000000000000000000000000100000002000000110000000ACD80000000000000000000000000000000000000000000010000000200000018000000
Routes=C0A80A0000000000000000000000000000000000000000000100000002000000180000000AC80000000000000000000000000000000000000000000001000000
Routes=02000000180000000ACD00000000000000000000000000000000000000000000
NumNrptRules=3
NrptRules=02000000020000000E000000000000000000000000000000020000000AC9010E000000000000000000000000020000000AC9010F000000000000000000000000
NrptRules=2E00740065007200670072006F00750070002E006E00650074000000020000000200000012000000000000000000000000000000020000000AC9010E00000000
NrptRules=0000000000000000020000000AC9010F0000000000000000000000002E0063006F00720065002E00770069006E0064006F00770073002E006E00650074000000
NrptRules=02000000020000001100000000000000000000000000000002000000010101020000000000000000000000000200000009090909000000000000000000000000
NrptRules=760070006E002E00740065007200670072006F00750070002E0063006F006D000000
AutoTiggerCapable=0
NumAppIds=0
NumClassicAppIds=0
SecurityDescriptor=
ApnInfoProviderId=
ApnInfoUsername=
ApnInfoPassword=
ApnInfoAccessPoint=
ApnInfoAuthentication=0
ApnInfoCompression=0
DeviceComplianceEnabled=0
DeviceComplianceSsoEnabled=0
DeviceComplianceSsoEku=
DeviceComplianceSsoIssuer=
WebAuthEnabled=0
WebAuthClientId=
FlagsSet=2083
Options=2
DisableDefaultDnsSuffixes=1
NumTrustedNetworks=1
TrustedNetworks=740065007200670072006F00750070002E006E006500740000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
TrustedNetworks=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
NumDnsSearchSuffixes=1
DnsSuffixSearchList=740065007200670072006F00750070002E006E006500740000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
DnsSuffixSearchList=00000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000
PowershellCreatedProfile=0
ProxyFlags=0
ProxySettingsModified=0
ProvisioningAuthority=
AuthTypeOTP=0
GREKeyDefined=0
NumPerAppTrafficFilters=0
AlwaysOnCapable=0
DeviceTunnel=0
PrivateNetwork=1

NETCOMPONENTS=
ms_msclient=1
ms_server=1

MEDIA=rastapi
Port=VPN2-0
Device=WAN Miniport (SSTP)

DEVICE=vpn
PhoneNumber=vpn.terchemicals.com
AreaCode=
CountryCode=0
CountryID=0
UseDialingRules=0
Comment=
FriendlyName=
LastSelectedPhone=0
PromoteAlternates=0
TryNextAlternateOnFail=1
'
    #endregion

    #region Installation vom VPN Profil
    $rasphonepath = "$env:appdata\Microsoft\Network\Connections\Pbk"
    $hiddenrasphonepath = "$env:appdata\Microsoft\Network\Connections\Pbk\_hiddenPbk"

    $hiddenpbkexist = Test-Path -Path $hiddenrasphonepath
    if ($hiddenpbkexist) { remove-item -Path $hiddenrasphonepath -recurse }

    $rasphone = "$rasphonepath\rasphone.pbk"
    $pbkexist = Test-Path -Path $rasphone
    if ($pbkexist) { 
        $rasphone_pre_config = (Get-Content "$rasphonepath\rasphone.pbk") -join "`n"
        $rasphone_config = $rasphone_pre_config + "`n`n" + "[$Profilename]" + $Pbk_config
        remove-item -path $rasphone -force
        New-Item -Path $rasphonepath -Name "rasphone.pbk" -ItemType "file" -Value $rasphone_config
    }
    else { New-Item -Path $rasphonepath -Name "rasphone.pbk" -ItemType "file" -Value  ("`n`n" + "[$Profilename]" + $Pbk_config) }
#endregion
}
TER-New-VPNConnection -ProfileName 'TERGroup Extern VPN 4.0'